vfbLib.cmdline
==============

.. automodule:: vfbLib.cmdline
  
   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      vfb2json
      vfb2ufo
   
   

   
   
   

   
   
   



